@@ -1,4 +1,4 @@
-use ginepro::LoadBalancedChannelBuilder;
+use ginepro::LoadBalancedChannel;
 
 use shared_proto::pb::{echo_client::EchoClient, EchoRequest};
 
@@ -6,7 +6,7 @@ use shared_proto::pb::{echo_client::EchoClient, EchoRequest};
 async fn main() -> Result<(), Box<dyn std::error::Error>> {
     // Create a load balanced channel that connects to localhost:5000.
     // Here the service discovery will update the set of servers every 5 seconds.
-    let channel = LoadBalancedChannelBuilder::new_with_service(("localhost", 5000_u16))
+    let channel = LoadBalancedChannel::builder(("localhost", 5000_u16))
         .await?
         .dns_probe_interval(std::time::Duration::from_secs(5))
         .channel();
